#!/bin/sh

SYSTEM=`uname -s`
CURRENTDATE=`date +%F-%H-%M-%N`
echo
echo "XGI $SYSTEM driver installation for package `cat version`"
echo 

#############################################
## 0. Get the distribution information
#############################################
Distrib_SE="/etc/SuSE-release"
Distrib_MD="/etc/mandrake-release"
Distrib_FC="/etc/fedora-release"
Distrib_RF="/etc/redflag-release"
Distrib_RH="/etc/redhat-release"
Distrib="other"

#check OS
if [ -f $Distrib_RF ] ; then
	Distrib="redflag"
elif [ -f $Distrib_MD ] ; then
	Distrib="mandrake"
elif [ -f $Distrib_FC ] ; then
	Distrib="fedora"
elif [ -f $Distrib_SE ] ; then
	Distrib="suse"
elif [ -f $Distrib_RH ] ; then
	Distrib="redhat" 
else 
	Distrib="other"
fi

echo $Distrib
#############################################
## 1. Copy 2D driver
#############################################
driver_bin="xgi_drv.o"

if [ "$X11R6" = "" ] ; then
	# echo "The system do not contains the X11R6 environment variable." 1>&2
	# echo "Use /usr/X11R6 as default X11R6 path." 1>&2
	# echo
	# echo
	X11R6=/usr/X11R6
	export X11R6
fi

if [ "$MACHTYPE" = "" ] ; then
	MACHTYPE=i386
fi

MACH=`echo $MACHTYPE | sed 's/-.*$//g'` ;

if [ "$MACH" = "x86_64" ] ; then
	# 64 bit
	driver_path=${X11R6}/lib64/modules/drivers

	if [ ! -d $driver_path ] ; then
		driver_path=${X11R6}/lib/modules/drivers
	fi
else
	# 32 bit	
	driver_path=${X11R6}/lib/modules/drivers
fi

DRV="${driver_path}/xgi_drv.o"

if [ ! -d "$driver_path" ] ; then
	echo "Cannot open X11 installation path $driver_path. Exit." 1>&2
	exit -1 ;
fi

if [ -f xgi_drv.o ] ; then 
	install -m 644 $driver_bin $driver_path
	echo "Driver xgi_drv.o copy to ${driver_path} done."
else
	echo "There is no xgi_drv.o existing." 1>&2
	exit -1 ;
fi

# Probe HW and generate /etc/sysconfig/hwconf
if [ -f /usr/sbin/kudzu ] ; then
	kudzu -q
fi

################################################
## 2. modify configuration
################################################

##
# If Redhat or Fedora, Begin
##

if [ "$Distrib" = "redhat" ] || [ "$Distrib" = "fedora" ] ; then

	# patch /usr/share/hwdata/Cards and /usr/share/hwdata/pcitable
	
	if [ -f /usr/share/hwdata/Cards ] ; then
		echo "Backup original Cards Information..."
		cp /usr/share/hwdata/Cards /usr/share/hwdata/Cards.backup.xgi
		echo "Add XGI Cards Information..."
		perl xgicfg_redhat.plx -f "/usr/share/hwdata/Cards" -a "Cards.xgi" -t Cards
		cp /usr/share/hwdata/Cards.new /usr/share/hwdata/Cards
	fi
	
	if [ -f /usr/share/hwdata/pcitable ] ; then
		echo "Backup original pcitable Information..."
		cp /usr/share/hwdata/pcitable /usr/share/hwdata/pcitable.backup.xgi
		echo "Add XGI pcitable Information..."
		perl xgicfg_redhat.plx -f "/usr/share/hwdata/pcitable" -a "pcitable.xgi" -t pcitable
		cp /usr/share/hwdata/pcitable.new /usr/share/hwdata/pcitable	
	fi
	
	SYSTEM_CONFIG_DISPLAY="/usr/bin/system-config-display"
	CONFIG_DISPLAY_RH_XF86="/usr/bin/redhat-config-xfree86"
	CONFIG_DISPLAY_RH_XORG="/usr/bin/redhat-config-xorg"
	
	if [ -f $CONFIG_DISPLAY_RH_XORG ] ; then
		SYSTEM_CONFIG_DISPLAY=$CONFIG_DISPLAY_RH_XORG
	elif [ -f $CONFIG_DISPLAY_RH_XF86 ] ; then
		SYSTEM_CONFIG_DISPLAY=$CONFIG_DISPLAY_RH_XF86
	fi
	
	if [ -f $SYSTEM_CONFIG_DISPLAY ] ; then
		echo "run x configuration...using $SYSTEM_CONFIG_DISPLAY"
		if [ "$Distrib" = "fedora" ] && [ "$MACH" = "i386" ] ; then
			$SYSTEM_CONFIG_DISPLAY --noui
		else
			$SYSTEM_CONFIG_DISPLAY --reconfig --noui
		fi
		echo "finished."
	else
		echo "$SYSTEM_CONFIG_DISPLAY does not exist. Please run xf86config."	
	fi

	# Probe HW and generate /etc/sysconfig/hwconf
	if [ -f /usr/sbin/kudzu ] ; then
		kudzu -q
	fi

	exit 0
fi

##
# Finish Redhat X configuration
##

#================================================================

##
# SuSE Begin
##

if [ "$Distrib" = "suse" ] ; then
	# patch /usr/X11/lib/sax/api/data/cdb/Cards
	# patch /usr/X11/lib/sax/sysp/maps/Identity.map
	# patch /usr/X11/lib/sax/sysp/maps/Vendor.map
	CARDS=/usr/X11/lib/sax/api/data/cdb/Cards
	IDENTITY=/usr/X11/lib/sax/sysp/maps/Identity.map
	VENDOR=/usr/X11/lib/sax/sysp/maps/Vendor.map
		
	if [ "$MACH" = "x86_64" ] ; then
		CARDS=/usr/X11/lib64/sax/api/data/cdb/Cards
		IDENTITY=/usr/X11/lib64/sax/sysp/maps/Identity.map
		VENDOR=/usr/X11/lib64/sax/sysp/maps/Vendor.map
	fi
	if [ -f $CARDS ] ; then
		echo "Backup original Cards Information..."
		cp $CARDS $CARDS.backup.xgi
		echo "Add XGI Cards Information..."
		perl xgicfg_suse.plx -f "$CARDS" -a "Cards.xgi.suse" -t Cards
		cp $CARDS.new $CARDS
	fi
	
	if [ -f $IDENTITY ] ; then
		echo "Backup original Identity.map Information..."
		cp $IDENTITY $IDENTITY.backup.xgi
		echo "Add XGI identity Information..."
		perl xgicfg_suse.plx -f "$IDENTITY" -a "Identity.xgi" -t identity
		cp $IDENTITY.new $IDENTITY
	fi

	
	if [ -f $VENDOR ] ; then
		echo "Backup original Vendor.map Information..."
		cp $VENDOR $VENDOR.backup.xgi
		echo "Add XGI Vendor Information..."
		perl xgicfg_suse.plx -f "$VENDOR" -a "Vendor.xgi" -t vendor
		cp $VENDOR.new $VENDOR
	fi

	SYSTEM_CONFIG_DISPLAY="/usr/X11/bin/sax2"
	
	if [ -f $SYSTEM_CONFIG_DISPLAY ] ; then
		echo "run x configuration...using $SYSTEM_CONFIG_DISPLAY"
		CHIPNO=`$SYSTEM_CONFIG_DISPLAY -p |grep 0x18ca | sed 's/is.*$//g' |sed 's/Chip://g'`
		$SYSTEM_CONFIG_DISPLAY -r -u -a -c $CHIPNO
		echo "finished."
	else
		echo "$SYSTEM_CONFIG_DISPLAY does not exist. Please run xf86config."	
	fi 
	exit 0

fi

##
# SuSE End
##

#================================================================

##
# Mandrake Begin
## 

if [ "$Distrib" = "mandrake" ] ; then
	# patch /usr/share/ldetect-lst/Cards+
	# patch /usr/share/ldetect-lst/pcitable

	if [ -f /usr/share/ldetect-lst/Cards+ ] ; then
		echo "Backup original Cards Information..."
		cp /usr/share/ldetect-lst/Cards+ /usr/share/ldetect-lst/Cards+.backup.xgi
		echo "Add XGI Cards Information..."
		perl xgicfg_mandrake.plx -f "/usr/share/ldetect-lst/Cards+" -a "Cards.xgi" -t Cards
		cp /usr/share/ldetect-lst/Cards+.new /usr/share/ldetect-lst/Cards+
	fi
	
	if [ -f /usr/share/ldetect-lst/pcitable ] ; then
		echo "Backup original pcitable Information..."
		cp /usr/share/ldetect-lst/pcitable /usr/share/ldetect-lst/pcitable.backup.xgi
		echo "Add XGI pcitable Information..."
		perl xgicfg_mandrake.plx -f "/usr/share/ldetect-lst/pcitable" -a "pcitable.xgi" -t pcitable
		cp /usr/share/ldetect-lst/pcitable.new /usr/share/ldetect-lst/pcitable	
	fi
	
	# next step, configure XF86Config/xorg.conf directly

fi


##
# Mandrake End
##


#===============================================================

##
# RedFlag Begin
## 

if [ "$Distrib" = "redflag" ] ; then
	# patch /usr/share/hwdata/Cards and /usr/share/hwdata/pcitable
	
	if [ -f /usr/share/hwdata/Cards ] ; then
		echo "Backup original Cards Information..."
		cp /usr/share/hwdata/Cards /usr/share/hwdata/Cards.backup.xgi
		echo "Add XGI Cards Information..."
		perl xgicfg_redhat.plx -f "/usr/share/hwdata/Cards" -a "Cards.xgi" -t Cards
		cp /usr/share/hwdata/Cards.new /usr/share/hwdata/Cards
	fi
	
	if [ -f /usr/share/hwdata/pcitable ] ; then
		echo "Backup original pcitable Information..."
		cp /usr/share/hwdata/pcitable /usr/share/hwdata/pcitable.backup.xgi
		echo "Add XGI pcitable Information..."
		perl xgicfg_redhat.plx -f "/usr/share/hwdata/pcitable" -a "pcitable.xgi" -t pcitable
		cp /usr/share/hwdata/pcitable.new /usr/share/hwdata/pcitable	
	fi

	
	# next step, configure XF86Config/xorg.conf directly

fi


##
# RedFlag End
##


#===============================================================

#
# Other distributions
#
	XFREE86_CFG="/etc/X11/XF86Config"
	XFREE86_BAK="/etc/X11/.XF86Config.bak"
	
	XORG_CFG="/etc/X11/xorg.conf"
	XORG_BAK="/etc/X11/.xorg.conf.bak"
	
	RF_XFREE86_CFG="/etc/X11/XF86Config-4"
	RF_XFREE86_BAK="/etc/X11/.XF86Config-4.bak"
	
	CFG=$XFREE86_CFG
	BAK=$XFREE86_BAK
	
	if [ -f $XFREE86_CFG ] ; then
		CFG=$XFREE86_CFG
		BAK=$XFREE86_BAK
		XSERVER_MODULE="XFree86"
	fi
	
	if [ -f $XORG_CFG ] ; then
		CFG=$XORG_CFG
		BAK=$XORG_BAK
		XSERVER_MODULE="XOrg"
	fi
	
	if [ -f $RF_XFREE86_CFG ] ; then
		CFG=$RF_XFREE86_CFG
		BAK=$RF_XFREE86_BAK
		XSERVER_MODULE="XFree86"
	fi
	#echo "$CFG $BAK"	
	perl xgicfg.plx $CFG $BAK
	
	if [ ! -f ${CFG} ] ; then
		echo "Cannot find X configuration file $CFG . Please run xf86config." 1>&2 
		exit -1 ;
	fi
	
# Finish Configuration


